ENSEMBL PRODUCTION INFRASTRUCTURE CORE PACKAGE 
 =============================================
[![Build Status](https://app.travis-ci.com/Ensembl/ensembl-prodinf-core.svg&branch=main)](https://app.travis-ci.com/Ensembl/ensembl-prodinf-core)
![Coverage Status](https://coveralls.io/repos/github/Ensembl/ensembl-prodinf-core/badge.svg?branch=main)

Contain shared libraries used across other production team manages python packages





